/*= R&S AFQ I/Q Modulation Generator Include File ===========================*/
/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSAFQ_HEADER
#define __RSAFQ_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                    (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE                   (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE        (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER8                   (_VI_ERROR+0x3FFC0808L)
#define VI_ERROR_INSTR_PARAMETER9                   (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10                  (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11                  (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12                  (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13                  (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14                  (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15                  (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                          (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define RSAFQ_ERROR_INSTRUMENT_ERROR                (VI_ERROR_INSTR_OFFSET + 0xF0L)
/* Add instrument driver specific error codes here */

#define RSAFQ_ERROR_INVALID_CONFIGURATION           (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSAFQ_ERROR_INSTRUMENT_OPTION               (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSAFQ_ERROR_INSTRUMENT_NSUP_MODEL           (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSAFQ_ERROR_SETTINGS_CONFLICT               (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSAFQ_ERROR_CALIBRATION_FAILED              (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSAFQ_ERROR_INSTRUMENT_NSUP_FUNC            (VI_ERROR_INSTR_OFFSET + 0xF6L)
/* Add instrument driver specific warning codes here */
#define RSAFQ_WARNING_SMALL_BUFFER                  (VI_WARNING_INSTR_OFFSET + 0xF1L)

/* Baseband Signal */

// Trigger
#define RSAFQ_TRIGGER_STATUS_STOP                   0
#define RSAFQ_TRIGGER_STATUS_RUN                    1
    
#define RSAFQ_INPUT_DATA_IMPEDANCE_G50              0
#define RSAFQ_INPUT_DATA_IMPEDANCE_G1K              1

#define RSAFQ_TRIGGER_MODE_CONTINUOUS               0
#define RSAFQ_TRIGGER_MODE_SINGLE                   1

#define RSAFQ_TRIGGER_SOURCE_BUS                    0
#define RSAFQ_TRIGGER_SOURCE_EXTERNAL               1
#define RSAFQ_TRIGGER_SOURCE_MANUAL                 2
#define RSAFQ_TRIGGER_SOURCE_AUTO                   3

#define RSAFQ_SEGMENT_TRIGGER_SOURCE_BUS            0
#define RSAFQ_SEGMENT_TRIGGER_SOURCE_MANUAL         1
#define RSAFQ_SEGMENT_TRIGGER_SOURCE_EXTERNAL       2
#define RSAFQ_SEGMENT_TRIGGER_SOURCE_AUTO           3

#define RSAFQ_INPUT_TRIGGER_SLOPE_NEGATIVE          0
#define RSAFQ_INPUT_TRIGGER_SLOPE_POSITIVE          1

#define RSAFQ_INPUT_TRIGGER_SEGMENT_SLOPE_NEGATIVE  0
#define RSAFQ_INPUT_TRIGGER_SEGMENT_SLOPE_POSITIVE  1   
    
#define RSAFQ_MSEGMENT_TRIGGER_MODE_CONTINUOUS      0
#define RSAFQ_MSEGMENT_TRIGGER_MODE_SEAMLESS        1
#define RSAFQ_MSEGMENT_TRIGGER_MODE_SINGLE          2
#define RSAFQ_MSEGMENT_TRIGGER_MODE_AUTO            3
    
#define RSAFQ_WSEGMENT_NEXT_MODE_AINC               0
#define RSAFQ_WSEGMENT_NEXT_MODE_FPAR               1
#define RSAFQ_WSEGMENT_NEXT_MODE_FSER               2

// Marker
#define RSAFQ_MARKER_TYPE_UNCHANGED                 0
#define RSAFQ_MARKER_TYPE_RESTART                   1
#define RSAFQ_MARKER_TYPE_PULSE                     2
#define RSAFQ_MARKER_TYPE_PATTERN                   3
#define RSAFQ_MARKER_TYPE_RATIO                     4
#define RSAFQ_MARKER_TYPE_LIST                      5

// Clock
#define RSAFQ_CLOCK_SOURCE_INTERNAL                 0
#define RSAFQ_CLOCK_SOURCE_EXTERNAL                 1

#define RSAFQ_CLOCK_INPUT_SLOPE_NEGATIVE            0
#define RSAFQ_CLOCK_INPUT_SLOPE_POSITIVE            1

#define RSAFQ_ROSC_SOURCE_INTERNAL                  0
#define RSAFQ_ROSC_SOURCE_EXTERNAL                  1

#define RSAFQ_ROSC_SBAN_WIDE                        0
#define RSAFQ_ROSC_SBAN_NARROW                      1
    
#define RSAFQ_ROSC_SYNC_MODE_NORM                   0
#define RSAFQ_ROSC_SYNC_MODE_MAST                   1
#define RSAFQ_ROSC_SYNC_MODE_SLAV                   2
#define RSAFQ_ROSC_SYNC_MODE_LAST                   3

/* Equalizer */

// Equalizer Modulator
#define RSAFQ_EQUALIZER_MODULATOR_FEM_ABSOLUTE      0
#define RSAFQ_EQUALIZER_MODULATOR_FEM_RELATIVE      1

/* Output */

#define RSAFQ_OUTPUT_ANALOG                         0
#define RSAFQ_OUTPUT_DIGITAL                        1   
#define RSAFQ_OUTPUT_ANALOG1                        2
#define RSAFQ_OUTPUT_ANALOG2                        3
#define RSAFQ_OUTPUT_DIGITAL1                       4
#define RSAFQ_OUTPUT_DIGITAL2                       5
#define RSAFQ_OUTPUT_BASEBAND                       6

// Analog Outputs
#define RSAFQ_OUTPUT_ANALOG_TYPE_BALANCED           0
#define RSAFQ_OUTPUT_ANALOG_TYPE_UNBALANCED         1

#define RSAFQ_OUTPUT_ANALOG_AMPL_MODE_ELECTRONIC    0
#define RSAFQ_OUTPUT_ANALOG_AMPL_MODE_ATTENUATORS   1

#define RSAFQ_OUTPUT_IMPEDANCE_R50                  0
#define RSAFQ_OUTPUT_IMPEDANCE_HIGH                 1

// Digital Outputs
#define RSAFQ_OUTPUT_DIGITAL_CLK_SOURCE_INTERNAL    0
#define RSAFQ_OUTPUT_DIGITAL_CLK_SOURCE_EXTERNAL    1

#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT6        0
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT7        1
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT8        2
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT9        3
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT10       4
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT11       5
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT12       6
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT13       7
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT14       8
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT15       9
#define RSAFQ_OUTPUT_DIGITAL_RESOLUTION_BIT16       10

#define RSAFQ_OUTPUT_DIGITAL_PORT1                  0
#define RSAFQ_OUTPUT_DIGITAL_PORT2                  1

#define RSAFQ_OUTPUT_DIGITAL_PASS_SIGNAL            0
#define RSAFQ_OUTPUT_DIGITAL_PASS_MARKER            1

/* Bit error Rate (BERT) */

// Configure
#define RSAFQ_BERT_MODE_AUTO                        0
#define RSAFQ_BERT_MODE_SINGLE                      1

#define RSAFQ_BERT_PRBS_PRBS9                       0
#define RSAFQ_BERT_PRBS_PRBS11                      1
#define RSAFQ_BERT_PRBS_PRBS15                      2
#define RSAFQ_BERT_PRBS_PRBS16                      3
#define RSAFQ_BERT_PRBS_PRBS20                      4
#define RSAFQ_BERT_PRBS_PRBS21                      5
#define RSAFQ_BERT_PRBS_PRBS23                      6

#define RSAFQ_BERT_CLOCK_POLARITY_RISING            0
#define RSAFQ_BERT_CLOCK_POLARITY_FALLING           1

#define RSAFQ_BERT_DATA_POLARITY_NORMAL             0
#define RSAFQ_BERT_DATA_POLARITY_INVERTED           1

#define RSAFQ_BERT_DATA_ENABLE_OFF                  0
#define RSAFQ_BERT_DATA_ENABLE_LOW                  1
#define RSAFQ_BERT_DATA_ENABLE_HIGH                 2

#define RSAFQ_BERT_PATTERN_IGNORE_OFF               0
#define RSAFQ_BERT_PATTERN_IGNORE_ONE               1
#define RSAFQ_BERT_PATTERN_IGNORE_ZERO              2

#define RSAFQ_BERT_IMP_G50                          0
#define RSAFQ_BERT_IMP_G1K                          1

#define RSAFQ_BERT_DISPLAY_UNIT_ENG                 0   
#define RSAFQ_BERT_DISPLAY_UNIT_SCI                 1
#define RSAFQ_BERT_DISPLAY_UNIT_PCT                 2
#define RSAFQ_BERT_DISPLAY_UNIT_PPM                 3

/* General Instrument Settings */

// Diagnostics Subsystems
#define RSAFQ_DIAGNOSTIC_FCONTROL_AUTO              0   
#define RSAFQ_DIAGNOSTIC_FCONTROL_FSPEED            1

// STATus Subsystems
#define RSAFQ_REGISTER_OPERATION                    0
#define RSAFQ_REGISTER_QUESTIONABLE                 1

#define RSAFQ_REGISTER_COND                         0
#define RSAFQ_REGISTER_EVENT                        1
#define RSAFQ_REGISTER_ENABLE                       2
#define RSAFQ_REGISTER_NTR                          3
#define RSAFQ_REGISTER_PTR                          4

/* Utility Functions */
#define RSAFQ_INSTRUMENT_AFQ100A                    0
#define RSAFQ_INSTRUMENT_AFQ100B                    1

#define RSAFQ_OPT_B10                               0  
#define RSAFQ_OPT_B11                               1  
#define RSAFQ_OPT_B13                               2  
#define RSAFQ_OPT_B14                               3  
#define RSAFQ_OPT_B15                               4  
#define RSAFQ_OPT_B16                               5  
#define RSAFQ_OPT_B17                               6  
#define RSAFQ_OPT_B20                               7  
#define RSAFQ_OPT_B22                               8  
#define RSAFQ_OPT_B30                               9  
#define RSAFQ_OPT_B31                               10 
#define RSAFQ_OPT_B32                               11 
#define RSAFQ_OPT_B35                               12 
#define RSAFQ_OPT_B36                               13 
#define RSAFQ_OPT_B37                               14 
#define RSAFQ_OPT_B81                               15 
#define RSAFQ_OPT_B82                               16 
#define RSAFQ_OPT_B102                              17 
#define RSAFQ_OPT_B202                              18 
#define RSAFQ_OPT_B103                              19 
#define RSAFQ_OPT_B203                              20 
#define RSAFQ_OPT_B104                              21 
#define RSAFQ_OPT_B106                              22 
#define RSAFQ_OPT_K5                                23
#define RSAFQ_OPT_K11                               24
#define RSAFQ_OPT_K12                               25
#define RSAFQ_OPT_K13                               26
#define RSAFQ_OPT_K14                               27
#define RSAFQ_OPT_K15                               28
#define RSAFQ_OPT_K17                               29
#define RSAFQ_OPT_K19                               30
#define RSAFQ_OPT_K20                               31
#define RSAFQ_OPT_K40                               32
#define RSAFQ_OPT_K42                               33
#define RSAFQ_OPT_K43                               34
#define RSAFQ_OPT_K44                               35
#define RSAFQ_OPT_K46                               36
#define RSAFQ_OPT_K48                               37
#define RSAFQ_OPT_K49                               38
#define RSAFQ_OPT_K61                               39
#define RSAFQ_OPT_K62                               40
#define RSAFQ_OPT_K71                               41
#define RSAFQ_OPT_K80                               42

/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/
    
ViStatus _VI_FUNC rsafq_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC rsafq_SetARBState (ViSession instrumentHandle, ViBoolean state);
ViStatus _VI_FUNC rsafq_GetARBState (ViSession instrumentHandle, ViBoolean* state);
ViStatus _VI_FUNC rsafq_ARBSetToDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_GetCrestFactor (ViSession instrumentHandle,
                                        ViReal64* crestFactor);
ViStatus _VI_FUNC rsafq_ARBWaveformCatalog (ViSession instrumentHandle,
                                            ViString directoryPath,
                                            ViInt32 arraySize,
                                            ViChar _VI_FAR waveformCatalog[]);
ViStatus _VI_FUNC rsafq_ARBWaveformCatalogLength (ViSession instrumentHandle,
                                                  ViString filePath,
                                                  ViInt32* waveformCatalogLength);
ViStatus _VI_FUNC rsafq_ARBWaveformDataWrite (ViSession instrumentHandle,
                                              ViString fileName, ViInt32 arraySize,
                                              ViString waveformData);
ViStatus _VI_FUNC rsafq_ARBWaveformDelete (ViSession instrumentHandle,
                                           ViString waveformName);
ViStatus _VI_FUNC rsafq_ARBWaveformPoints (ViSession instrumentHandle,
                                           ViInt32* waveformPoints);
ViStatus _VI_FUNC rsafq_ARBWaveformSelect (ViSession instrumentHandle,
                                           ViString waveformSelect);
ViStatus _VI_FUNC rsafq_ARBWaveformTag (ViSession instrumentHandle,
                                        ViInt32 arraySize, ViString waveformTag,
                                        ViChar _VI_FAR waveformTagData[]);
ViStatus _VI_FUNC rsafq_ARBWaveformResample(ViSession   instrSession,
    										ViString    waveformSelect);
ViStatus _VI_FUNC rsafq_GetARBWaveformResampleFrequency(ViSession   instrSession,
    										ViReal64*   resampleFrequency);
ViStatus _VI_FUNC rsafq_SetTSIGSampleClock(ViSession   instrSession,
											ViReal64    sampleClock);

ViStatus _VI_FUNC rsafq_GetTSIGSampleClock (ViSession instrumentHandle,
                                            ViReal64 *sampleClock);

ViStatus _VI_FUNC rsafq_ConfigureTSIGSine (ViSession instrumentHandle,
                                           ViReal64 sampleClock,
                                           ViInt32 samples_perPeriod,
                                           ViReal64 phaseOffsetQ);

ViStatus _VI_FUNC rsafq_GetTSIGSineResultingFrequency (ViSession instrumentHandle,
                                                       ViReal64 *resultingFrequency);

ViStatus _VI_FUNC rsafq_GenerateTSIGSine (ViSession instrumentHandle,
                                          ViBoolean storeToHDD,
                                          ViString waveformFilename);

ViStatus _VI_FUNC rsafq_SetTSIGSineSamplesPerPeriod (ViSession instrumentHandle,
                                                     ViInt32 samples_perPeriod);

ViStatus _VI_FUNC rsafq_GetTSIGSineSamplesPerPeriod (ViSession instrumentHandle,
                                                     ViInt32 *samples_perPeriod);

ViStatus _VI_FUNC rsafq_SetTSIGSinePhaseOffsetQ (ViSession instrumentHandle,
                                                 ViReal64 phaseOffsetQ);

ViStatus _VI_FUNC rsafq_GetTSIGSinePhaseOffsetQ (ViSession instrumentHandle,
                                                 ViReal64 *phaseOffsetQ);

ViStatus _VI_FUNC rsafq_ConfigureTSIGRectangular (ViSession instrumentHandle,
                                                  ViReal64 sampleClock,
                                                  ViInt32 samples_perPeriod,
                                                  ViReal64 amplitude,
                                                  ViReal64 offset);

ViStatus _VI_FUNC rsafq_GenerateTSIGRectangular (ViSession instrumentHandle,
                                                 ViBoolean storeToHDD,
                                                 ViString waveformFilename);

ViStatus _VI_FUNC rsafq_SetTSIGRectangularSamplesPerPeriod (ViSession instrumentHandle,
                                                            ViInt32 samples_perPeriod);

ViStatus _VI_FUNC rsafq_GetTSIGRectangularSamplesPerPeriod (ViSession instrumentHandle,
                                                            ViInt32 *samples_perPeriod);

ViStatus _VI_FUNC rsafq_SetTSIGRectangularAmplitude (ViSession instrumentHandle,
                                                     ViReal64 amplitude);

ViStatus _VI_FUNC rsafq_GetTSIGRectangularAmplitude (ViSession instrumentHandle,
                                                     ViReal64 *amplitude);

ViStatus _VI_FUNC rsafq_SetTSIGRectangularOffset (ViSession instrumentHandle,
                                                  ViReal64 offset);

ViStatus _VI_FUNC rsafq_GetTSIGRectangularOffset (ViSession instrumentHandle,
                                                  ViReal64 *offset);

ViStatus _VI_FUNC rsafq_ConfigureTSIGTableSineCommon (ViSession instrumentHandle,
                                                      ViReal64 sampleClock,
                                                      ViInt32 tableLength,
                                                      ViReal64 offset);

ViStatus _VI_FUNC rsafq_ConfigureTSIGTableSine (ViSession instrumentHandle,
                                                ViInt32 sine, ViInt32 periods,
                                                ViReal64 amplitude,
                                                ViReal64 phase);

ViStatus _VI_FUNC rsafq_GetTSIGTableSineResultingFrequency (ViSession instrumentHandle,
                                                            ViInt32 sine,
                                                            ViReal64 *resultingFrequency);

ViStatus _VI_FUNC rsafq_GenerateTSIGTableSine (ViSession instrumentHandle,
                                               ViBoolean storeToHDD,
                                               ViString waveformFilename);

ViStatus _VI_FUNC rsafq_SetTSIGTableSineLength (ViSession instrumentHandle,
                                                ViInt32 tableLength);

ViStatus _VI_FUNC rsafq_GetTSIGTableSineLength (ViSession instrumentHandle,
                                                ViInt32 *tableLength);

ViStatus _VI_FUNC rsafq_SetTSIGTableSineOffset (ViSession instrumentHandle,
                                                ViReal64 offset);

ViStatus _VI_FUNC rsafq_GetTSIGTableSineOffset (ViSession instrumentHandle,
                                                ViReal64 *offset);

ViStatus _VI_FUNC rsafq_SetTSIGTableSinePeriods (ViSession instrumentHandle,
                                                 ViInt32 sine, ViInt32 periods);

ViStatus _VI_FUNC rsafq_GetTSIGTableSinePeriods (ViSession instrumentHandle,
                                                 ViInt32 sine, ViInt32 *periods);

ViStatus _VI_FUNC rsafq_SetTSIGTableSineAmplitude (ViSession instrumentHandle,
                                                   ViInt32 sine,
                                                   ViReal64 amplitude);

ViStatus _VI_FUNC rsafq_GetTSIGTableSineAmplitude (ViSession instrumentHandle,
                                                   ViInt32 sine,
                                                   ViReal64 *amplitude);

ViStatus _VI_FUNC rsafq_SetTSIGTableSinePhase (ViSession instrumentHandle,
                                               ViInt32 sine, ViReal64 phase);

ViStatus _VI_FUNC rsafq_GetTSIGTableSinePhase (ViSession instrumentHandle,
                                               ViInt32 sine, ViReal64 *phase);

ViStatus _VI_FUNC rsafq_ConfigureTSIGPattern (ViSession instrumentHandle,
                                              ViInt32 i, ViInt32 q);

ViStatus _VI_FUNC rsafq_GenerateTSIGPattern (ViSession instrumentHandle,
                                             ViBoolean storeToHDD,
                                             ViString waveformFilename);

ViStatus _VI_FUNC rsafq_SetTSIGPatternI (ViSession instrumentHandle, ViInt32 i);

ViStatus _VI_FUNC rsafq_GetTSIGPatternI (ViSession instrumentHandle, ViInt32 *i);

ViStatus _VI_FUNC rsafq_SetTSIGPatternQ (ViSession instrumentHandle, ViInt32 q);

ViStatus _VI_FUNC rsafq_GetTSIGPatternQ (ViSession instrumentHandle, ViInt32 *q);

ViStatus _VI_FUNC rsafq_GetTriggerStatus (ViSession instrumentHandle,
                                          ViInt32* triggerStatus);
ViStatus _VI_FUNC rsafq_ConfigureDataInput (ViSession instrumentHandle,
                                       ViInt32 dataInputImpedance,
                                       ViReal64 dataInputThreshold);
ViStatus _VI_FUNC rsafq_ConfigureTrigger (ViSession instrumentHandle,
                                          ViInt32 triggerMode, ViBoolean retrigger,
                                          ViInt32 triggerSource,
                                          ViReal64 externalDelay,
                                          ViReal64 externalInhibit,
                                          ViInt32 inputTriggerSlope);
ViStatus _VI_FUNC rsafq_ConfigureSegmentTrigger (ViSession instrumentHandle,
                                                 ViInt32 multiSegmentTriggerMode,
                                                 ViInt32 segmentTriggerSource,
                                                 ViReal64 segmentExternalDelay,
                                                 ViReal64 segmentExternalInhibit,
                                                 ViInt32 inputTriggerSlope);
ViStatus _VI_FUNC rsafq_TriggerExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_SetTriggerMode (ViSession instrumentHandle,
                                        ViInt32 triggerMode);
ViStatus _VI_FUNC rsafq_GetTriggerMode (ViSession instrumentHandle,
                                        ViInt32* triggerMode);
ViStatus _VI_FUNC rsafq_SetTriggerSource (ViSession instrumentHandle,
                                          ViInt32 triggerSource);
ViStatus _VI_FUNC rsafq_GetTriggerSource (ViSession instrumentHandle,
                                          ViInt32* triggerSource);

ViStatus _VI_FUNC rsafq_SetTriggerCount (ViSession instrumentHandle,
                                         ViInt32 triggerCount);

ViStatus _VI_FUNC rsafq_GetTriggerCount (ViSession instrumentHandle,
                                         ViInt32 *triggerCount);

ViStatus _VI_FUNC rsafq_SetExternalDelay (ViSession instrumentHandle,
                                          ViReal64 externalDelay);
ViStatus _VI_FUNC rsafq_GetExternalDelay (ViSession instrumentHandle,
                                          ViReal64* externalDelay);
ViStatus _VI_FUNC rsafq_SetExternalInhibit (ViSession instrumentHandle,
                                            ViReal64 externalInhibit);
ViStatus _VI_FUNC rsafq_GetExternalInhibit (ViSession instrumentHandle,
                                            ViReal64* externalInhibit);
ViStatus _VI_FUNC rsafq_SetImpedanceDataInput (ViSession instrumentHandle,
                                               ViInt32 dataInputImpedance);
ViStatus _VI_FUNC rsafq_GetImpedanceDataInput (ViSession instrumentHandle,
                                               ViInt32 *dataInputImpedance);
ViStatus _VI_FUNC rsafq_SetThresholdDataInput (ViSession instrumentHandle,
                                               ViReal64 dataInputThreshold);
ViStatus _VI_FUNC rsafq_GetThresholdDataInput (ViSession instrumentHandle,
                                               ViReal64 *dataInputThreshold);
ViStatus _VI_FUNC rsafq_SetInstrumentTriggerInputSlope (ViSession instrumentHandle,
                                                        ViInt32 inputTriggerSlope);
ViStatus _VI_FUNC rsafq_GetInstrumentTriggerInputSlope (ViSession instrumentHandle,
                                                        ViInt32* inputTriggerSlope);
ViStatus _VI_FUNC rsafq_SetRetriggerEnable (ViSession instrumentHandle,
                                            ViBoolean retrigger);
ViStatus _VI_FUNC rsafq_GetRetriggerEnable (ViSession instrumentHandle,
                                            ViBoolean* rettriger);
ViStatus _VI_FUNC rsafq_SegmentTriggerExecute (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_SetMultiSegmentTriggerMode (ViSession instrumentHandle,
                                                    ViInt32 multiSegmentTriggerMode);
ViStatus _VI_FUNC rsafq_GetMultiSegmentTriggerMode (ViSession instrumentHandle,
                                                    ViInt32* multiSegmentTriggerMode);
ViStatus _VI_FUNC rsafq_SetSegmentTriggerSource (ViSession instrumentHandle,
                                                 ViInt32 segmentTriggerSource);
ViStatus _VI_FUNC rsafq_GetSegmentTriggerSource (ViSession instrumentHandle,
                                                 ViInt32* segmentTriggerSource);

ViStatus _VI_FUNC rsafq_SetSegmentTriggerCount (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViInt32 triggerCount[]);

ViStatus _VI_FUNC rsafq_GetSegmentTriggerCount (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViInt32 triggerCount[]);

ViStatus _VI_FUNC rsafq_SetSegmentExternalDelay (ViSession instrumentHandle,
                                                 ViReal64 segmentExternalDelay);
ViStatus _VI_FUNC rsafq_GetSegmentExternalDelay (ViSession instrumentHandle,
                                                 ViReal64* segmentExternalDelay);
ViStatus _VI_FUNC rsafq_SetSegmentExternalInhibit (ViSession instrumentHandle,
                                                   ViReal64 segmentExternalInhibit);
ViStatus _VI_FUNC rsafq_GetSegmentExternalInhibit (ViSession instrumentHandle,
                                                   ViReal64* segmentExternalInhibit);
ViStatus _VI_FUNC rsafq_SetSegmentTriggerInputSlope (ViSession instrumentHandle,
                                                     ViInt32 inputTriggerSlope);
ViStatus _VI_FUNC rsafq_GetSegmentTriggerInputSlope (ViSession instrumentHandle,
                                                     ViInt32* inputTriggerSlope);
ViStatus _VI_FUNC rsafq_GetWaveformSegments (ViSession instrumentHandle,
                                             ViInt32* segment);
ViStatus _VI_FUNC rsafq_SetNextWaveformSegment (ViSession instrumentHandle,
                                                ViInt32 nextSegment);
ViStatus _VI_FUNC rsafq_GetNextWaveformSegment (ViSession instrumentHandle,
                                                ViInt32* nextSegment);
ViStatus _VI_FUNC rsafq_SetNextWaveformSegmentMode (ViSession instrumentHandle,
                                                    ViInt32 nextWaveformSegmentMode);
ViStatus _VI_FUNC rsafq_GetNextWaveformSegmentMode (ViSession instrumentHandle,
                                                    ViInt32 *nextWaveformSegmentMode);
ViStatus _VI_FUNC rsafq_ConfigureMarkerMode (ViSession instrumentHandle,
                                             ViInt32 markerOutput,
                                             ViInt32 markerType,
                                             ViInt32 markerPulseDivider,
                                             ViInt32 patternCount,
                                             ViBoolean markerPattern[],
                                             ViInt32 markerONTime,
                                             ViInt32 markerOFFTime);
ViStatus _VI_FUNC rsafq_SetMarkerMode (ViSession instrumentHandle,
                                       ViInt32 markerOutput, ViInt32 markerType);
ViStatus _VI_FUNC rsafq_GetMarkerMode (ViSession instrumentHandle,
                                       ViInt32 markerOutput, ViInt32* markerType);
ViStatus _VI_FUNC rsafq_SetMarkerPattern (ViSession instrumentHandle,
                                          ViInt32 markerOutput,
                                          ViInt32 patternCount,
                                          ViBoolean markerPattern[]);
ViStatus _VI_FUNC rsafq_GetMarkerPattern (ViSession instrumentHandle,
                                          ViInt32 markerOutput, ViInt32 patternCount,
                                          ViBoolean _VI_FAR markerPattern[]);
ViStatus _VI_FUNC rsafq_SetMarkerOFFTime (ViSession instrumentHandle,
                                          ViInt32 markerOutput,
                                          ViInt32 markerOFFTime);
ViStatus _VI_FUNC rsafq_GetMarkerOFFTime (ViSession instrumentHandle,
                                          ViInt32 markerOutput,
                                          ViInt32* markerOFFTime);
ViStatus _VI_FUNC rsafq_SetMarkerONTime (ViSession instrumentHandle,
                                         ViInt32 markerOutput,
                                         ViInt32 markerONTime);
ViStatus _VI_FUNC rsafq_GetMarkerONTime (ViSession instrumentHandle,
                                         ViInt32 markerOutput,
                                         ViInt32* markerONTime);
ViStatus _VI_FUNC rsafq_SetMarkerPulseDivider (ViSession instrumentHandle,
                                               ViInt32 markerOutput,
                                               ViInt32 markerPulseDivider);
ViStatus _VI_FUNC rsafq_GetMarkerPulseDivider (ViSession instrumentHandle,
                                               ViInt32 markerOutput,
                                               ViInt32* markerPulseDivider);
ViStatus _VI_FUNC rsafq_GetMarkerPulseFrequency (ViSession instrumentHandle,
                                                 ViInt32 markerOutput,
                                                 ViReal64* markerPulseFrequency);

ViStatus _VI_FUNC rsafq_SetMarkerList (ViSession instrumentHandle,
                                       ViInt32 markerOutput, ViString markerList);

ViStatus _VI_FUNC rsafq_GetMarkerList (ViSession instrumentHandle,
                                       ViInt32 markerOutput, ViChar markerList[],
                                       ViInt32 arraySize);

ViStatus _VI_FUNC rsafq_SetMarkerDelay (ViSession instrumentHandle,
                                        ViInt32 markerOutput, ViInt32 markerDelay);
ViStatus _VI_FUNC rsafq_GetMarkerDelay (ViSession instrumentHandle,
                                        ViInt32 markerOutput, ViInt32* markerDelay);
ViStatus _VI_FUNC rsafq_SetFixMarkerDelayToCurrentRange (ViSession instrumentHandle,
                                                         ViBoolean fixedMarkerDelay);
ViStatus _VI_FUNC rsafq_GetFixMarkerDelayToCurrentRange (ViSession instrumentHandle,
                                                         ViBoolean* fixedMarkerDelay);
ViStatus _VI_FUNC rsafq_GetFixedMarkerDelayMaximum (ViSession instrumentHandle,
                                                    ViInt32 markerOutput,
                                                    ViReal64* fixedMarkerDelayMaximum);
ViStatus _VI_FUNC rsafq_GetFixedMarkerDelayMinimum (ViSession instrumentHandle,
                                                    ViInt32 markerOutput,
                                                    ViReal64* fixedMarkerDelayMinimum);
ViStatus _VI_FUNC rsafq_ConfigureClock (ViSession instrumentHandle,
                                        ViInt32 clockSource,
                                        ViReal64 clockFrequency, ViInt32 inputSlope,
                                        ViReal64 thresholdDataInput,
                                        ViInt32 impedanceDataInput,
                                        ViInt32 ROSCSource,
                                        ViInt32 roscSynchronizationBandwidth);
ViStatus _VI_FUNC rsafq_SetClockSource (ViSession instrumentHandle,
                                        ViInt32 clockSource);
ViStatus _VI_FUNC rsafq_GetClockSource (ViSession instrumentHandle,
                                        ViInt32* clockSource);
ViStatus _VI_FUNC rsafq_SetClockFrequency (ViSession instrumentHandle,
                                           ViReal64 clockFrequency);
ViStatus _VI_FUNC rsafq_GetClockFrequency (ViSession instrumentHandle,
                                           ViReal64* clockFrequency);
ViStatus _VI_FUNC rsafq_SetClockInputSlope (ViSession instrumentHandle,
                                            ViInt32 inputSlope);
ViStatus _VI_FUNC rsafq_GetClockInputSlope (ViSession instrumentHandle,
                                            ViInt32* inputSlope);

ViStatus _VI_FUNC rsafq_GetClockWidebandMode (ViSession instrumentHandle,
                                              ViBoolean *widebandMode);

ViStatus _VI_FUNC rsafq_ClockInputFrequency (ViSession instrumentHandle,
                                             ViReal64* clockInputFrequency);
ViStatus _VI_FUNC rsafq_SetROSCSource (ViSession instrumentHandle,
                                       ViInt32 ROSCSource);
ViStatus _VI_FUNC rsafq_GetROSCSource (ViSession instrumentHandle,
                                       ViInt32* ROSCSource);
ViStatus _VI_FUNC rsafq_SetROSCSynchronizationBandwidth (ViSession instrumentHandle,
                                                         ViInt32 ROSCSynchronizationBandwidth);
ViStatus _VI_FUNC rsafq_GetROSCSynchronizationBandwidth (ViSession instrumentHandle,
                                                         ViInt32* ROSCSynchronizationBandwidth);
ViStatus _VI_FUNC rsafq_SetROSCSynchronizationMode (ViSession instrumentHandle,
                                                    ViInt32 ROSCSynchronizationMode);
ViStatus _VI_FUNC rsafq_GetROSCSynchronizationMode (ViSession instrumentHandle,
                                                    ViInt32 *ROSCSynchronizationMode);

ViStatus _VI_FUNC rsafq_SetROSCDelay (ViSession instrumentHandle, ViReal64 delay);

ViStatus _VI_FUNC rsafq_GetROSCDelay (ViSession instrumentHandle,
                                      ViReal64 *delay);

ViStatus _VI_FUNC rsafq_ConfigureTimeShifts (ViSession instrumentHandle,
                                             ViReal64 iPathDelay,
                                             ViReal64 qPathDelay,
                                             ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsafq_SetIPathDelay (ViSession instrumentHandle,
                                       ViReal64 iPathDelay);
ViStatus _VI_FUNC rsafq_GetIPathDelay (ViSession instrumentHandle,
                                       ViReal64* iPathDelay);
ViStatus _VI_FUNC rsafq_SetQPathDelay (ViSession instrumentHandle,
                                       ViReal64 qPathDelay);
ViStatus _VI_FUNC rsafq_GetQPathDelay (ViSession instrumentHandle,
                                       ViReal64* qPathDelay);
ViStatus _VI_FUNC rsafq_SetFrequencyOffset (ViSession instrumentHandle,
                                            ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsafq_GetFrequencyOffset (ViSession instrumentHandle,
                                            ViReal64* frequencyOffset);
ViStatus _VI_FUNC rsafq_ConfigureIQImpairment (ViSession instrumentHandle,
                                               ViReal64 iGain, ViReal64 qGain,
                                               ViReal64 iOffset, ViReal64 qOffset,
                                               ViReal64 phaseMismatch);
ViStatus _VI_FUNC rsafq_SetIQModulationImpairmentsState (ViSession instrumentHandle,
                                                         ViBoolean impairmentsState);
ViStatus _VI_FUNC rsafq_GetIQModulationImpairmentsState (ViSession instrumentHandle,
                                                         ViBoolean* impairmentsState);
ViStatus _VI_FUNC rsafq_SetIQModulationIOffset (ViSession instrumentHandle,
                                                ViReal64 iOffset);
ViStatus _VI_FUNC rsafq_GetIQModulationIOffset (ViSession instrumentHandle,
                                                ViReal64* iOffset);
ViStatus _VI_FUNC rsafq_SetIQModulationQOffset (ViSession instrumentHandle,
                                                ViReal64 qOffset);
ViStatus _VI_FUNC rsafq_GetIQModulationQOffset (ViSession instrumentHandle,
                                                ViReal64* qOffset);
ViStatus _VI_FUNC rsafq_SetIQModulationGainIPath (ViSession instrumentHandle,
                                                  ViReal64 iGain);
ViStatus _VI_FUNC rsafq_GetIQModulationGainIPath (ViSession instrumentHandle,
                                                  ViReal64* iGain);
ViStatus _VI_FUNC rsafq_SetIQModulationGainQPath (ViSession instrumentHandle,
                                                  ViReal64 qGain);
ViStatus _VI_FUNC rsafq_GetIQModulationGainQPath (ViSession instrumentHandle,
                                                  ViReal64* qGain);
ViStatus _VI_FUNC rsafq_SetIQModulationPhase (ViSession instrumentHandle,
                                              ViReal64 phaseMismatch);
ViStatus _VI_FUNC rsafq_GetIQModulationPhase (ViSession instrumentHandle,
                                              ViReal64* phaseMismatch);
ViStatus _VI_FUNC rsafq_SetEqualizerState (ViSession instrumentHandle,
                                           ViBoolean equalizerState);
ViStatus _VI_FUNC rsafq_GetEqualizerState (ViSession instrumentHandle,
                                           ViBoolean* equalizerState);
ViStatus _VI_FUNC rsafq_SetEqualizerIQState (ViSession instrumentHandle,
                                             ViBoolean IQState);
ViStatus _VI_FUNC rsafq_GetEqualizerIQState (ViSession instrumentHandle,
                                             ViBoolean* IQState);
ViStatus _VI_FUNC rsafq_EqualizerIQCatalog (ViSession instrumentHandle,
                                            ViInt32 arraySize,
                                            ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQCatalogLength (ViSession instrumentHandle,
                                                     ViString filePath,
                                                     ViInt32* catalogLength);
ViStatus _VI_FUNC rsafq_EqualizerIQISelect (ViSession instrumentHandle,
                                            ViString fileName);
ViStatus _VI_FUNC rsafq_EqualizerIQQSelect (ViSession instrumentHandle,
                                            ViString fileName);
ViStatus _VI_FUNC rsafq_DeleteIQEqualizerData (ViSession instrumentHandle,
                                               ViString fileName);
ViStatus _VI_FUNC rsafq_ConfigureEqualizerIQITable (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR iFrequency[],
                                                    ViReal64 _VI_FAR iGain[],
                                                    ViReal64 _VI_FAR iPhase[]);
ViStatus _VI_FUNC rsafq_ConfigureEqualizerIQQTable (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR qFrequency[],
                                                    ViReal64 _VI_FAR qGain[],
                                                    ViReal64 _VI_FAR qPhase[]);
ViStatus _VI_FUNC rsafq_SetEqualizerIQIFrequency (ViSession instrumentHandle,
                                                  ViInt32 arraySize,
                                                  ViReal64 _VI_FAR iFrequency[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQIFrequency (ViSession instrumentHandle,
                                                  ViInt32 arraySize,
                                                  ViReal64 _VI_FAR iFrequency[]);
ViStatus _VI_FUNC rsafq_SetEqualizerIQQFrequency (ViSession instrumentHandle,
                                                  ViInt32 arraySize,
                                                  ViReal64 _VI_FAR qFrequency[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQQFrequency (ViSession instrumentHandle,
                                                  ViInt32 arraySize,
                                                  ViReal64 _VI_FAR qFrequency[]);
ViStatus _VI_FUNC rsafq_SetEqualizerIQIGain (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR iGain[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQIGain (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR iGain[]);
ViStatus _VI_FUNC rsafq_SetEqualizerIQQGain (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR qGain[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQQGain (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR qGain[]);
ViStatus _VI_FUNC rsafq_SetEqualizerIQIPhase (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViReal64 _VI_FAR iPhase[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQIPhase (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViReal64 _VI_FAR iPhase[]);
ViStatus _VI_FUNC rsafq_SetEqualizerIQQPhase (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViReal64 _VI_FAR qPhase[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQQPhase (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViReal64 _VI_FAR qPhase[]);
ViStatus _VI_FUNC rsafq_GetEqualizerIQIPoints (ViSession instrumentHandle,
                                               ViInt32* numberOfDataIPoints);
ViStatus _VI_FUNC rsafq_GetEqualizerIQQPoints (ViSession instrumentHandle,
                                               ViInt32* numberOfDataQPoints);
ViStatus _VI_FUNC rsafq_SetEqualizerModulatorState (ViSession instrumentHandle,
                                                    ViBoolean modulatorState);
ViStatus _VI_FUNC rsafq_GetEqualizerModulatorState (ViSession instrumentHandle,
                                                    ViBoolean* modulatorState);
ViStatus _VI_FUNC rsafq_SetFrequencyEntryMode (ViSession instrumentHandle,
                                               ViInt32 frequencyEntryMode);
ViStatus _VI_FUNC rsafq_GetFrequencyEntryMode (ViSession instrumentHandle,
                                               ViInt32* frequencyEntryMode);
ViStatus _VI_FUNC rsafq_EqualizerModulatorCatalog (ViSession instrumentHandle,
                                                   ViInt32 arraySize,
                                                   ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rsafq_GetEqualizerModulatorCatalogLength
             (ViSession instrumentHandle, ViString filePath,
              ViInt32* catalogLength);
ViStatus _VI_FUNC rsafq_EqualizerModulatorSelect (ViSession instrumentHandle,
                                                  ViString fileName);
ViStatus _VI_FUNC rsafq_DeleteEqualizerModulatorData (ViSession instrumentHandle,
                                                      ViString fileName);
ViStatus _VI_FUNC rsafq_ConfigureEqualizerModulatorTable (ViSession instrumentHandle,
                                                          ViInt32 arraySize,
                                                          ViReal64 _VI_FAR frequency[],
                                                          ViReal64 _VI_FAR gain[],
                                                          ViReal64 _VI_FAR phase[]);
ViStatus _VI_FUNC rsafq_SetEqualizerModulatorFrequency (ViSession instrumentHandle,
                                                        ViInt32 arraySize,
                                                        ViReal64 _VI_FAR frequency[]);
ViStatus _VI_FUNC rsafq_GetEqualizerModulatorFrequency (ViSession instrumentHandle,
                                                        ViInt32 arraySize,
                                                        ViReal64 _VI_FAR frequency[]);
ViStatus _VI_FUNC rsafq_SetEqualizerModulatorGain (ViSession instrumentHandle,
                                                   ViInt32 arraySize,
                                                   ViReal64 _VI_FAR gain[]);
ViStatus _VI_FUNC rsafq_GetEqualizerModulatorGain (ViSession instrumentHandle,
                                                   ViInt32 arraySize,
                                                   ViReal64 _VI_FAR gain[]);
ViStatus _VI_FUNC rsafq_SetEqualizerModulatorPhase (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR phase[]);
ViStatus _VI_FUNC rsafq_GetEqualizerModulatorPhase (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR phase[]);
ViStatus _VI_FUNC rsafq_SetRFFrequency (ViSession instrumentHandle,
                                        ViReal64 RFFrequency);
ViStatus _VI_FUNC rsafq_GetRFFrequency (ViSession instrumentHandle,
                                        ViReal64* RFFrequency);
ViStatus _VI_FUNC rsafq_GetEqualizerModulatorPoints (ViSession instrumentHandle,
                                                     ViInt32* numberOfDataPoints);
ViStatus _VI_FUNC rsafq_SetOutputState (ViSession instrumentHandle,
                                        ViBoolean outputState);
ViStatus _VI_FUNC rsafq_GetOutputState (ViSession instrumentHandle,
                                        ViBoolean* outputState);
ViStatus _VI_FUNC rsafq_SetActiveOutput (ViSession instrumentHandle,
                                         ViInt32 activeOutput);
ViStatus _VI_FUNC rsafq_GetActiveOutput (ViSession instrumentHandle,
                                         ViInt32* activeOutput);
ViStatus _VI_FUNC rsafq_ConfigureAnalogOutput (ViSession instrumentHandle,
                                               ViBoolean outputState,
                                               ViInt32 analogOutput, ViInt32 type,
                                               ViReal64 amplitude,
                                               ViInt32 amplitudeMode,
                                               ViReal64 iOffset, ViReal64 qOffset,
                                               ViBoolean enableBias, ViReal64 bias);
ViStatus _VI_FUNC rsafq_SetAnalogOutputType (ViSession instrumentHandle,
                                             ViInt32 analogOutput, ViInt32 type);
ViStatus _VI_FUNC rsafq_GetAnalogOutputType (ViSession instrumentHandle,
                                             ViInt32 analogOutput, ViInt32* type);
ViStatus _VI_FUNC rsafq_SetAnalogOutputAmplitudeMode (ViSession instrumentHandle,
                                                      ViInt32 analogOutput,
                                                      ViInt32 amplitudeMode);
ViStatus _VI_FUNC rsafq_GetAnalogOutputAmplitudeMode (ViSession instrumentHandle,
                                                      ViInt32 analogOutput,
                                                      ViInt32* amplitudeMode);
ViStatus _VI_FUNC rsafq_SetAnalogOutputImpedance (ViSession instrumentHandle,
                                                  ViInt32 analogOutput,
                                                  ViInt32 outputImpedance);
ViStatus _VI_FUNC rsafq_GetAnalogOutputImpedance (ViSession instrumentHandle,
                                                  ViInt32 analogOutput,
                                                  ViInt32* outputImpedance);
ViStatus _VI_FUNC rsafq_SetAnalogOutputEqualizerState (ViSession instrumentHandle,
                                                       ViInt32 analogOutput,
                                                       ViBoolean equalizerState);
ViStatus _VI_FUNC rsafq_GetAnalogOutputEqualizerState (ViSession instrumentHandle,
                                                       ViInt32 analogOutput,
                                                       ViBoolean* equalizerState);
ViStatus _VI_FUNC rsafq_SetAnalogOutputBalancedAmplitude (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViReal64 amplitude);
ViStatus _VI_FUNC rsafq_GetAnalogOutputBalancedAmplitude (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViReal64* amplitude);
ViStatus _VI_FUNC rsafq_SetAnalogOutputUnbalancedAmplitude
             (ViSession instrumentHandle, ViInt32 analogOutput, ViReal64 amplitude);
ViStatus _VI_FUNC rsafq_GetAnalogOutputUnbalancedAmplitude
             (ViSession instrumentHandle, ViInt32 analogOutput,
              ViReal64* amplitude);
ViStatus _VI_FUNC rsafq_SetAnalogOutputBalancedIOffset (ViSession instrumentHandle,
                                                        ViInt32 analogOutput,
                                                        ViReal64 iOffset);
ViStatus _VI_FUNC rsafq_GetAnalogOutputBalancedIOffset (ViSession instrumentHandle,
                                                        ViInt32 analogOutput,
                                                        ViReal64* iOffset);
ViStatus _VI_FUNC rsafq_SetAnalogOutputBalancedQOffset (ViSession instrumentHandle,
                                                        ViInt32 analogOutput,
                                                        ViReal64 qOffset);
ViStatus _VI_FUNC rsafq_GetAnalogOutputBalancedQOffset (ViSession instrumentHandle,
                                                        ViInt32 analogOutput,
                                                        ViReal64* qOffset);
ViStatus _VI_FUNC rsafq_SetAnalogOutputUnbalancedIOffset (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViReal64 iOffset);
ViStatus _VI_FUNC rsafq_GetAnalogOutputUnbalancedIOffset (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViReal64* iOffset);
ViStatus _VI_FUNC rsafq_SetAnalogOutputUnbalancedQOffset (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViReal64 qOffset);
ViStatus _VI_FUNC rsafq_GetAnalogOutputUnbalancedQOffset (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViReal64* qOffset);
ViStatus _VI_FUNC rsafq_SetAnalogOutputBalancedBiasState (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViBoolean enableBias);
ViStatus _VI_FUNC rsafq_GetAnalogOutputBalancedBiasState (ViSession instrumentHandle,
                                                          ViInt32 analogOutput,
                                                          ViBoolean* enableBias);
ViStatus _VI_FUNC rsafq_SetAnalogOutputBalancedBias (ViSession instrumentHandle,
                                                     ViInt32 analogOutput,
                                                     ViReal64 bias);
ViStatus _VI_FUNC rsafq_GetAnalogOutputBalancedBias (ViSession instrumentHandle,
                                                     ViInt32 analogOutput,
                                                     ViReal64* bias);
ViStatus _VI_FUNC rsafq_ConfigureDigitalOutput (ViSession instrumentHandle,
                                                ViBoolean outputState,
                                                ViInt32 digitalOutput,
                                                ViInt32 port, ViInt32 resolution,
                                                ViReal64 amplitude,
                                                ViReal64 iOffset,
                                                ViReal64 qOffset, ViReal64 rate,
                                                ViInt32 source,
                                                ViInt32 i0_maps_to,
                                                ViInt32 i1_maps_to,
                                                ViInt32 q0_maps_to,
                                                ViInt32 q1_maps_to);
ViStatus _VI_FUNC rsafq_SetDigitalOutputClockRate(ViSession instrumentHandle,
                                                  ViInt32 digitalOutput,
                                                  ViReal64 rate);
ViStatus _VI_FUNC rsafq_GetDigitalOutputClockRate(ViSession instrumentHandle,
                                                  ViInt32 digitalOutput,
                                                  ViReal64* rate);
ViStatus _VI_FUNC rsafq_SetDigitalOutputClockSource(ViSession instrumentHandle,
                                                    ViInt32 digitalOutput,
                                                    ViInt32 source);
ViStatus _VI_FUNC rsafq_GetDigitalOutputClockSource(ViSession instrumentHandle,
                                                    ViInt32 digitalOutput,
                                                    ViInt32* source);

ViStatus _VI_FUNC rsafq_SetDigitalOutputClockSlope (
													ViSession 	instrSession,
												    ViInt32 	digitalOutput,
													ViInt32 	slope);

ViStatus _VI_FUNC rsafq_GetDigitalOutputClockSlope (ViSession instrSession,
                                                    ViInt32 digitalOutput,
                                                    ViInt32 *slope);

ViStatus _VI_FUNC rsafq_SetDigitalOutputSignalResolution (ViSession instrumentHandle,
                                                          ViInt32 digitalOutput,
                                                          ViInt32 resolution);
ViStatus _VI_FUNC rsafq_GetDigitalOutputSignalResolution (ViSession instrumentHandle,
                                                          ViInt32 digitalOutput,
                                                          ViInt32* resolution);
ViStatus _VI_FUNC rsafq_SetDigitalOutputSignalAmplitude (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViReal64 amplitude);
ViStatus _VI_FUNC rsafq_GetDigitalOutputSignalAmplitude (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViReal64* amplitude);
ViStatus _VI_FUNC rsafq_SetDigitalOutputSignalIOffset (ViSession instrumentHandle,
                                                       ViInt32 digitalOutput,
                                                       ViReal64 iOffset);
ViStatus _VI_FUNC rsafq_GetDigitalOutputSignalIOffset (ViSession instrumentHandle,
                                                       ViInt32 digitalOutput,
                                                       ViReal64* iOffset);
ViStatus _VI_FUNC rsafq_SetDigitalOutputSignalQOffset (ViSession instrumentHandle,
                                                       ViInt32 digitalOutput,
                                                       ViReal64 qOffset);
ViStatus _VI_FUNC rsafq_GetDigitalOutputSignalQOffset (ViSession instrumentHandle,
                                                       ViInt32 digitalOutput,
                                                       ViReal64* qOffset);
ViStatus _VI_FUNC rsafq_SetDigitalOutputInterfacePort (ViSession instrumentHandle,
                                                       ViInt32 digitalOutput,
                                                       ViInt32 port);
ViStatus _VI_FUNC rsafq_GetDigitalOutputInterfacePort (ViSession instrumentHandle,
                                                       ViInt32 digitalOutput,
                                                       ViInt32* port);
ViStatus _VI_FUNC rsafq_SetDigitalOutputPinI0Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32 i0_maps_to);
ViStatus _VI_FUNC rsafq_GetDigitalOutputPinI0Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32* i0_maps_to);
ViStatus _VI_FUNC rsafq_SetDigitalOutputPinI1Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32 i1_maps_to);
ViStatus _VI_FUNC rsafq_GetDigitalOutputPinI1Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32* i1_maps_to);
ViStatus _VI_FUNC rsafq_SetDigitalOutputPinQ0Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32 q0_maps_to);
ViStatus _VI_FUNC rsafq_GetDigitalOutputPinQ0Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32* q0_maps_to);
ViStatus _VI_FUNC rsafq_SetDigitalOutputPinQ1Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32 q1_maps_to);
ViStatus _VI_FUNC rsafq_GetDigitalOutputPinQ1Assignment (ViSession instrumentHandle,
                                                         ViInt32 digitalOutput,
                                                         ViInt32* q1_maps_to);
ViStatus _VI_FUNC rsafq_SetBERTState (ViSession instrumentHandle,
                                      ViBoolean BERTState);
ViStatus _VI_FUNC rsafq_GetBERTState (ViSession instrumentHandle,
                                      ViBoolean* BERTState);
ViStatus _VI_FUNC rsafq_BERTStartMeasurement (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_BERTStopMeasurement (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_BERTMeasurementResuts (ViSession instrumentHandle,
                                               ViInt32* dataBits, ViInt32* errors,
                                               ViReal64* bitErrorRate,
                                               ViInt32* terminationStatus,
                                               ViInt32* clockLineStatus,
                                               ViInt32* dataLineStatus,
                                               ViInt32* synchronizationStatus);
ViStatus _VI_FUNC rsafq_ConfigureBERT (ViSession instrumentHandle, ViInt32 mode,
                                       ViInt32 maxDataBits, ViInt32 maxErrors,
                                       ViInt32 PRBS, ViInt32 dataPolarity,
                                       ViInt32 clockSlope,
                                       ViBoolean externalRestart,
                                       ViInt32 dataEnable, ViInt32 patternIgnore,
                                       ViReal64 threshold, ViInt32 impedance);
ViStatus _VI_FUNC rsafq_SetBERTMode (ViSession instrumentHandle, ViInt32 mode);
ViStatus _VI_FUNC rsafq_GetBERTMode (ViSession instrumentHandle, ViInt32* mode);
ViStatus _VI_FUNC rsafq_BERTExecuteSingle (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_SetBERTMaxDataBits (ViSession instrumentHandle,
                                            ViInt32 maxDataBits);
ViStatus _VI_FUNC rsafq_GetBERTMaxDataBits (ViSession instrumentHandle,
                                            ViInt32* maxDataBits);
ViStatus _VI_FUNC rsafq_SetBERTMaxErrors (ViSession instrumentHandle,
                                          ViInt32 maxErrors);
ViStatus _VI_FUNC rsafq_GetBERTMaxErrors (ViSession instrumentHandle,
                                          ViInt32* maxErrors);
ViStatus _VI_FUNC rsafq_SetBERTPRBS (ViSession instrumentHandle, ViInt32 PRBS);
ViStatus _VI_FUNC rsafq_GetBERTPRBS (ViSession instrumentHandle, ViInt32* PRBS);
ViStatus _VI_FUNC rsafq_SetBERTClockSlope (ViSession instrumentHandle,
                                           ViInt32 clockSlope);
ViStatus _VI_FUNC rsafq_GetBERTClockSlope (ViSession instrumentHandle,
                                           ViInt32* clockSlope);
ViStatus _VI_FUNC rsafq_SetBERTDataPolarity (ViSession instrumentHandle,
                                             ViInt32 dataPolarity);
ViStatus _VI_FUNC rsafq_GetBERTDataPolarity (ViSession instrumentHandle,
                                             ViInt32* dataPolarity);
ViStatus _VI_FUNC rsafq_SetBERTExternalRestart (ViSession instrumentHandle,
                                                ViBoolean externalRestart);
ViStatus _VI_FUNC rsafq_GetBERTExternalRestart (ViSession instrumentHandle,
                                                ViBoolean* externalRestart);
ViStatus _VI_FUNC rsafq_SetBERTDataEnable (ViSession instrumentHandle,
                                           ViInt32 dataEnable);
ViStatus _VI_FUNC rsafq_GetBERTDataEnable (ViSession instrumentHandle,
                                           ViInt32* dataEnable);
ViStatus _VI_FUNC rsafq_SetBERTPatternIgnore (ViSession instrumentHandle,
                                              ViInt32 patternIgnore);
ViStatus _VI_FUNC rsafq_GetBERTPatternIgnore (ViSession instrumentHandle,
                                              ViInt32* patternIgnore);
ViStatus _VI_FUNC rsafq_SetBERTImpedance (ViSession instrumentHandle,
                                          ViInt32 impedance);
ViStatus _VI_FUNC rsafq_GetBERTImpedance (ViSession instrumentHandle,
                                          ViInt32* impedance);
ViStatus _VI_FUNC rsafq_SetBERTThreshold (ViSession instrumentHandle,
                                          ViReal64 threshold);
ViStatus _VI_FUNC rsafq_GetBERTThreshold (ViSession instrumentHandle,
                                          ViReal64* threshold);
ViStatus _VI_FUNC rsafq_SetBERTDisplayUnit (ViSession instrumentHandle,
                                            ViInt32 displayUnit);
ViStatus _VI_FUNC rsafq_GetBERTDisplayUnit (ViSession instrumentHandle,
                                            ViInt32* displayUnit);
ViStatus _VI_FUNC rsafq_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_EventStatusEnable (ViSession instrumentHandle,
                                           ViInt32 registerValue);
ViStatus _VI_FUNC rsafq_EventStatusQuery (ViSession instrumentHandle,
                                          ViInt32* registerValue);
ViStatus _VI_FUNC rsafq_IdentificationQuery (ViSession instrumentHandle,
                                             ViChar _VI_FAR instrumentIdentification[]);
ViStatus _VI_FUNC rsafq_IndividualStatusQuery (ViSession instrumentHandle,
                                               ViInt32* ISTFlag);
ViStatus _VI_FUNC rsafq_OperationComplete (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_OperationCompleteQuery (ViSession instrumentHandle,
                                                ViInt32* OPCState);
ViStatus _VI_FUNC rsafq_OptionIdentificationQuery (ViSession instrumentHandle,
                                                   ViChar _VI_FAR optionIdentification[]);
ViStatus _VI_FUNC rsafq_ParallelPollRegisterEnable (ViSession instrumentHandle,
                                                    ViInt32 registerValue);
ViStatus _VI_FUNC rsafq_ParallelPollRegisterQuery (ViSession instrumentHandle,
                                                   ViInt32* registerValue);
ViStatus _VI_FUNC rsafq_PowerOnStatusClear (ViSession instrumentHandle,
                                            ViInt32 registerValue);
ViStatus _VI_FUNC rsafq_PowerOnStatusClearQuery (ViSession instrumentHandle,
                                                 ViInt32* registerValue);
ViStatus _VI_FUNC rsafq_Recall (ViSession instrumentHandle,
                                ViInt32 instrumentStatus);
ViStatus _VI_FUNC rsafq_Save (ViSession instrumentHandle, ViInt32 instrumentStatus);
ViStatus _VI_FUNC rsafq_ServiceRequestEnable (ViSession instrumentHandle,
                                              ViInt32 registerValue);
ViStatus _VI_FUNC rsafq_ServiceRequestEnableQuery (ViSession instrumentHandle,
                                                   ViInt32* registerValue);
ViStatus _VI_FUNC rsafq_StatusByteQuery (ViSession instrumentHandle,
                                         ViInt32* statusByte);
ViStatus _VI_FUNC rsafq_Trigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_TriggerWaitOPC (ViSession instrumentHandle,
                                        ViInt32 timeout);
ViStatus _VI_FUNC rsafq_SelfTestQuery (ViSession instrumentHandle,
                                       ViInt32* errorCode);
ViStatus _VI_FUNC rsafq_WaittoContinue (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_CALibrationAll (ViSession instrumentHandle, ViInt32 timeout,
                                        ViInt32* response);
ViStatus _VI_FUNC rsafq_CALibrationAmplitude (ViSession instrumentHandle,
                                              ViInt32 analogOutput, ViInt32 timeout,
                                              ViInt32* response);

ViStatus _VI_FUNC rsafq_CalibrationAnalogOutputDelay (ViSession instrumentHandle,
                                                      ViInt32 analogOutput,
                                                      ViInt32 timeout,
                                                      ViInt32 *response);

ViStatus _VI_FUNC rsafq_DIAGnosticModules (ViSession instrumentHandle,
                                           ViString moduleName,
                                           ViInt32 arraySize,
                                           ViChar moduleConfiguration[]);
ViStatus _VI_FUNC rsafq_DIAGnosticTestPoints (ViSession instrumentHandle,
                                              ViInt32 arraySize,
                                              ViChar _VI_FAR testPoints[]);
ViStatus _VI_FUNC rsafq_DIAGnosticTestPointVoltages (ViSession instrumentHandle,
                                                     ViString testPointName,
                                                     ViReal64* measuredVoltage);
ViStatus _VI_FUNC rsafq_DIAGnosticAOUTTestPoints (ViSession instrumentHandle,
                                                  ViInt32 analogOutput,
                                                  ViInt32 arraySize,
                                                  ViChar _VI_FAR testPoints[]);
ViStatus _VI_FUNC rsafq_DIAGnosticAOUTTestPointVoltages (ViSession instrumentHandle,
                                                         ViInt32 analogOutput,
                                                         ViString testPointName,
                                                         ViReal64* measuredVoltage);
ViStatus _VI_FUNC rsafq_SetFanControl (ViSession instrumentHandle,
                                       ViInt32 fanSpeed);
ViStatus _VI_FUNC rsafq_GetFanControl (ViSession instrumentHandle,
                                       ViInt32* fanSpeed);
ViStatus _VI_FUNC rsafq_MMEMoryCatalog (ViSession instrumentHandle,
                                        ViString directoryPath, ViInt32 arraySize,
                                        ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsafq_MMEMoryCatalogLength (ViSession instrumentHandle,
                                              ViString directoryPath,
                                              ViInt32* catalogLength);
ViStatus _VI_FUNC rsafq_MMEMoryChangeDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rsafq_MMEMoryCopy (ViSession instrumentHandle,
                                     ViString sourcePath, ViString destinationPath);
ViStatus _VI_FUNC rsafq_MMEMoryBlockDataWrite (ViSession instrumentHandle,
                                               ViString fileName,
                                               ViInt32 binaryBlockLength,
                                               ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rsafq_MMEMoryBlockDataRead (ViSession instrumentHandle,
                                              ViString fileName,
                                              ViInt32 binaryBlockLength,
                                              ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rsafq_MMEMoryDirectoryCatalog (ViSession instrumentHandle,
                                                 ViString directoryPath,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rsafq_MMEMoryDirectoryCatalogLength (ViSession instrumentHandle,
                                                       ViString directoryPath,
                                                       ViInt32* catalogLength);
ViStatus _VI_FUNC rsafq_MMEMoryDelete (ViSession instrumentHandle,
                                       ViString fileName);
ViStatus _VI_FUNC rsafq_MMEMoryMakeDirectory (ViSession instrumentHandle,
                                              ViString directoryName);
ViStatus _VI_FUNC rsafq_MMEMoryMove (ViSession instrumentHandle,
                                     ViString fileSource, ViString fileDestination);
ViStatus _VI_FUNC rsafq_MMEMoryDrive (ViSession instrumentHandle,
                                      ViString driveName);
ViStatus _VI_FUNC rsafq_MMEMoryRemoveDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rsafq_setRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViInt32 value);
ViStatus _VI_FUNC rsafq_getRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViInt32* value);
ViStatus _VI_FUNC rsafq_setRegisterBit (ViSession instrumentHandle,
                                        ViInt32 registerGroup, ViInt32 bit,
                                        ViInt32 registerType, ViInt32 value);
ViStatus _VI_FUNC rsafq_getRegisterBit (ViSession instrumentHandle,
                                        ViInt32 registerGroup, ViInt32 bit,
                                        ViInt32 registerType, ViInt32* value);
ViStatus _VI_FUNC rsafq_STATusPreset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_SYSTemAllErrors (ViSession instrumentHandle,
                                         ViInt32 arraySize,
                                         ViChar _VI_FAR allErrors[]);
ViStatus _VI_FUNC rsafq_SYSTemErrorQueueAll (ViSession instrumentHandle,
                                             ViInt32 arraySize,
                                             ViChar _VI_FAR errorQueue[]);
ViStatus _VI_FUNC rsafq_SYSTemErrorQueueCodeAll (ViSession instrumentHandle,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR errorQueueCode[]);
ViStatus _VI_FUNC rsafq_SYSTemErrorQueueCodeNext (ViSession instrumentHandle,
                                                  ViInt32* errorQueueCodeNext);
ViStatus _VI_FUNC rsafq_SYSTemErrorQueueCount (ViSession instrumentHandle,
                                               ViInt32* errorQueueCount);
ViStatus _VI_FUNC rsafq_GetSYSTemVersion (ViSession instrumentHandle,
                                          ViChar _VI_FAR SCPIVersion[]);
ViStatus _VI_FUNC rsafq_SYSTemPreset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_DEVicePreset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_GetPurgeKey (ViSession instrumentHandle, ViInt32* key);
ViStatus _VI_FUNC rsafq_ARBWaveformPurge (ViSession instrumentHandle, ViInt32 key);
ViStatus _VI_FUNC rsafq_readToFile (ViSession instrumentHandle, ViString source,
                                    ViString destination);
ViStatus _VI_FUNC rsafq_writeFromFile (ViSession instrumentHandle, ViString source,
                                       ViString destination);
ViStatus _VI_FUNC rsafq_writeHugeFileStart (ViSession instrumentHandle,
                                            ViString source,
                                            ViString destination,
                                            ViInt64 *fileHandle);
ViStatus _VI_FUNC rsafq_contHugeFile (ViSession instrumentHandle,
                                      ViInt64 fileHandle, ViUInt32 offset,
                                      ViUInt32 blockLength, ViBoolean *end);
ViStatus _VI_FUNC rsafq_errorCheckState (ViSession instrumentHandle,
                                         ViBoolean stateChecking);
ViStatus _VI_FUNC rsafq_optionCheckState (ViSession instrumentHandle,
                                          ViBoolean optionChecking);
ViStatus _VI_FUNC rsafq_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rsafq_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViInt32* numBytesRead);
ViStatus _VI_FUNC rsafq_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rsafq_self_test (ViSession instrumentHandle,
                                   ViInt16* selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsafq_error_query (ViSession instrumentHandle, ViInt32* errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsafq_error_message (ViSession instrumentHandle,
                                       ViStatus statusCode,
                                       ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsafq_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsafq_delay (ViSession instrumentHandle, ViReal64 seconds);
ViStatus _VI_FUNC rsafq_close (ViSession instrumentHandle);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
