#include <visa.h>

/*= Useful Macros ===========================================================*/

/* - Basic Macros ---------------------------------------------------------- */

/* Error checking macro */
#define CHECKERR(fCal) if (rsafq_status = (fCal), rsafq_status < VI_SUCCESS) \
    return rsafq_status; else

/* Error checking macro with jump to the ERROR: label */
#define GOCHECKERR(fCal) if (rsafq_status = (fCal), rsafq_status < VI_SUCCESS) \
                            goto ERROR_LABEL; else

/* Parameter checking macro */
#define CHECKPARAM(fCal,param) if (fCal) return VI_ERROR_PARAMETER##param; else

/* Initialize default function parameters */
#define INIT\
    ViStatus            rsafq_status = VI_SUCCESS; \
    rsafq_instrRange    instrPtr; \
    CHECKERR (viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

/* Close function and return */
#define RETURN\
    return rsafq_status;

/* - Additional Macros ----------------------------------------------------- */

#define CHECKOPT(option) if (instrPtr->optionChecking)\
                         {\
                            if (!instrPtr->instrOptions.option)\
                                return RSAFQ_ERROR_INSTRUMENT_OPTION;\
                         }\
                         else

#define CHECKOPTCONT(option) if (instrPtr->optionChecking)\
                         {\
                            if (!instrPtr->instrOptions.option)\
                                rssma_status = RSAFQ_ERROR_INSTRUMENT_OPTION;\
                         }\
                         else
/* Check instrument version */
#define CHECKVER(version) if (instrPtr->errorChecking)\
                         {\
                            if (instrPtr->instrVer != version)\
                                return RSAFQ_ERROR_INSTRUMENT_NSUP_MODEL;\
                         }\
                         else
/* Remap parameter error code */
#define REMAP(par_in, par_out) if (rsafq_status == VI_ERROR_PARAMETER##par_in)\
                                    rsafq_status = VI_ERROR_PARAMETER##par_out;\
                                if (rsafq_status < VI_SUCCESS)\
                                    return rsafq_status; else

#define OPTDEF(opt) if (!strncmp("RSAFQ_OPT_K",#opt,strlen("RSAFQ_OPT_K"))){\
                                        for (tmp_i=0;tmp_i<RSAFQ_PATH_NUM;tmp_i++)\
                                            instrPtr->instrOption[tmp_i][opt] = 1;\
                                } else{\
                                    if (!strcmp(#opt,"RSAFQ_OPT_B10")||!strcmp(#opt,"RSAFQ_OPT_B11")||!strcmp(#opt,"RSAFQ_OPT_B35")||!strcmp(#opt,"RSAFQ_OPT_B36")||!strcmp(#opt,"RSAFQ_OPT_B37")||!strcmp(#opt,"RSAFQ_OPT_B202")||!strcmp("RSAFQ_OPT_B203",#opt)||!strcmp(#opt,"RSAFQ_OPT_B82")) {\
                                        instrPtr->instrOption[0][opt] = 1;\
                                        instrPtr->instrOption[1][opt] = 1;}\
                                    else{\
                                        tmp_i=0;\
                                        while((instrPtr->instrOption[tmp_i][opt] > 0) && (tmp_i < (RSAFQ_PATH_NUM-1)))\
                                            tmp_i++;\
                                        instrPtr->instrOption[tmp_i][opt] = 1;\
                                     }\
                                   }            

                                        
/* Check NULL pointer */
#define CHECKNULL(pointer, param) if (!pointer) return VI_ERROR_PARAMETER##param; else

/* Supported instruments */
#define AFQ100A         0
#define AFQ100B         1



/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rsafq_stringValPair is used in the rsafq_error_message function           */
/* rsafq_statusDataRanges is used to track session dependent status & ranges */
/*===========================================================================*/
typedef struct  rssma_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rsafq_tStringValPair;

typedef struct rssma_instrOptions
{
    int B10:1;
    int B11:1;
    int B18:1;
    int K0:1;
    int K80:1;
    int K6:1;
    int K240:1;
    int K242:1;
    int K243:1;
    int K244:1;
    int K245:1;
    int K246:1;
    int K248:1;
    int K249:1;
    int K250:1;
    int K251:1;
    int K256:1;
    int K261:1;
    int K262:1;
} rssma_tinstrOptions;

struct rsafq_statusDataRanges
{
    ViChar          instrDriverRevision[256];
    ViBoolean       errorChecking;
    ViBoolean       optionChecking;
    ViInt32         instrVer;
    rssma_tinstrOptions instrOptions;
};

typedef struct rsafq_statusDataRanges *rsafq_instrRange;

ViStatus rsafq_itemToConst (ViChar **array, ViString stringItem, ViPInt32 itemNo);
ViBoolean rsafq_invalidViBooleanRange (ViBoolean val);
ViBoolean rsafq_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rsafq_invalidViReal64Range (ViReal64 val, ViReal64 min,
                                       ViReal64 max);
ViBoolean rsafq_invalidViString (ViString val, ViUInt32 maxLength);
ViStatus rsafq_waitOnVisaEvent (ViSession instrSession,
                                 ViEventType eventTypeIn,
                                 ViUInt32 tmoIn, ViPUInt16 STB);
ViStatus rsafq_checkStatus (ViSession instrSession);
ViStatus rsafq_waitOPC (ViSession instrSession, ViPString command,
                        ViPString instrResp, ViInt32 timeout);
ViStatus rsafq_sendCmd (ViSession instrSession, ViString cmd);
ViStatus rsafq_setViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViStatus parameterErrorCode);
ViStatus rsafq_getViInt32 (ViSession instrSession,
                           ViString cmd,
                           ViInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus rsafq_setViInt32Hex (ViSession instrSession,
                              ViString cmd,
                              ViInt32 value,
                              ViInt32 min,
                              ViInt32 max,
                              ViStatus parameterErrorCode);
ViStatus rsafq_getViInt32Hex (ViSession instrSession,
                           ViString cmd,
                           ViInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus rsafq_setViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 value,
                           ViUInt32 min,
                           ViUInt32 max,
                           ViStatus parameterErrorCode);
ViStatus rsafq_getViUInt32 (ViSession instrSession,
                           ViString cmd,
                           ViUInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus rsafq_setViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean value,
                           ViStatus parameterErrorCode);
ViStatus rsafq_getViBoolean (ViSession instrSession,
                           ViString cmd,
                           ViBoolean *value,
                           ViStatus parameterErrorCode);
ViStatus rsafq_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViStatus parameterErrorCode);
ViStatus rsafq_getViReal64 (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViStatus parameterErrorCode);
ViStatus rsafq_setViReal64Units (ViSession instrSession,
                                 ViString cmd,
                                 ViReal64 value,
                                 ViString units,
                                 ViReal64 min,
                                 ViReal64 max,
                                 ViStatus parameterErrorCode);
ViStatus rsafq_setViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus rsafq_getViString (ViSession instrSession,
                            ViString cmd,
                            ViString value,
                            ViInt32 buffer_size,
                            ViStatus parameterErrorCode);
ViStatus rsafq_setViStringQuoted (ViSession instrSession,
                            ViString cmd,
                            ViString quotes,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus rsafq_getViStringQuoted (ViSession instrSession,
                                  ViString cmd,
                                  ViString quotes,
                                  ViInt32  arraySize,
                                  ViChar   value[],
                                  ViStatus parameterErrorValue);
ViStatus rsafq_setEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rsafq_getEnum (ViSession instrSession,
                        ViString cmd,
                        ViInt32 *value,
                        ViString list[],
                        ViStatus parameterErrorCode);
ViStatus rsafq_checkIndexInList (ViSession instrSession,
                                 ViInt32 index,
                                 ViString list[],
                                 ViStatus statusIfError);
ViStatus rsafq_getIndexFromString (ViSession instrSession,
                                   ViString string,
                                   ViString *list,
                                   ViInt32 *index);
ViStatus rsafq_getCatalog (ViSession instrSession,
                           ViString cmd,
                           ViInt32 arraySize,
                           ViChar* array,
                           ViInt32 parameterErrorCode);
ViStatus rsafq_getViReal64Array (ViSession instrSession,
                            ViString cmd,
                            ViReal64 *value,
                            ViInt32  count,
                            ViStatus parameterErrorCode);
ViStatus rsafq_getViInt32Array (ViSession instrSession,
                            ViString cmd,
                            ViInt32 *value,
                            ViInt32  count,
                            ViStatus parameterErrorCode);
ViStatus rsafq_readHexArrayToBin (ViSession instrSession,
                            ViString cmd,
                            ViChar array[],
                            ViInt32  expectedStreamLength,
                            ViInt32  bufferSize);
ViStatus rsafq_readDataUnknownLength(ViSession instrSession,
                                     ViChar **outBuffer,
                                     ViUInt32 *count);
ViStatus rsafq_checkInstrument (ViSession instrSession, ViInt32 instrument, ViBoolean generateErrorIfPresent);
